==> PPDF_1_2.zip: PubMedPDF/include/paper_desc.php <==
<?php
# PAPER_DESCRIPTION($array)
#------------------------------------------------------------------
# ʸꥹȤΥƥץ졼
#
#   array[pmid], xoopsuser name
#-------------------------------------------------------------------

function PAPER_DESCRIPTION($item, $user){
	include "conn.php";
	include "check_perm.php";

	# upload directory(relative pass)
	$sql = "SELECT * FROM ".$T_CONFIG." WHERE conf_name='updir2'";
	$res = mysql_query($sql, $conn);
	$row = mysql_fetch_array($res, MYSQL_ASSOC);

	$up_dir = $row["conf_value"];
	if(substr($up_dir,-1) != "/") $up_dir.="/";

	# show data
	for($i=0; $i<count($item); $i++){

		$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$item[$i]."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);

		$id = $item[$i];
		$a = $row["Author"];
		$t = $row["Title"];
		$v = $row["Volume"];
		$p = $row["Page"];
		$y = $row["Year"];
		$j = $row["Journal"];
		$abst = $row["Abstract"];
		$a_jp = $row["Author_JP"];
		$t_jp = $row["Title_JP"];
		$r_usr = $row["R_usr"];

		# get authors from database
		$author="";
		$a = explode(",",substr($a,0,-1));
		for($k=0; $k<count($a); $k++){
			$a[$k] = str_replace("[","",$a[$k]);
			$a[$k] = str_replace("]","",$a[$k]);
			$sql = "SELECT Author FROM ".$T_AUTHOR." WHERE id='".$a[$k]."'";
			$res = mysql_query($sql, $conn);
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$author.=$row["Author"].", ";
		}
		$author = substr($author,0,-2);

		# get journal from database
		$sql = "SELECT Journal,Journal_JP FROM ".$T_JOURNAL." WHERE id='".$j."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$j = $row["Journal"];
		$j_jp = $row["Journal_JP"];

		# abstract
		$show_ab = "";
		if($abst){			
			$show_ab = "[<a href=\"javascript:disp('include/paper_desc.php?abst=".$id."',500,300)\">Abstract</a>]";
		}
		

		#favorite
		$favorite = "[<a href=\"javascript:disp('include/paper_desc.php?pid=".$id."',500,110)\">favorite</a>]";

	
		#note
		$memo = "[<a href=\"javascript:disp('include/paper_desc.php?mid=".$id."',650,600)\">note ";
		 #private note num
		$sql = "SELECT * FROM ".$T_MEMO." WHERE data_id='".$id."' AND Public_flg='0' AND R_usr='".$user."'";
		$res = mysql_query($sql, $conn);
		$memo.= "(".mysql_num_rows($res);
		 #public note num
		$sql = "SELECT * FROM ".$T_MEMO." WHERE data_id='".$id."' AND Public_flg='1'";
		$res = mysql_query($sql, $conn);
		$memo.= "/".mysql_num_rows($res).")";
		$memo.= "</a>]";
	

		# download
		$show_dl = "";
		if ($id > 0) {
			if(file_exists($up_dir.$id.".pdf")){
				$show_dl = "[<a href=\"".$up_dir.$id.".pdf\" target=\"_blank\">PDF</a>]";
			}
		} else {
			$title = trim( $t );
			$title = substr( $title, 0, 10 );
			$file_name = $y."_".$author."_".$j."_".$v."_".$p."_".$title;
			$file_name = str_replace( array(' ', ','), array('_', '~'), $file_name );
			$file_name = $file_name.".pdf";

			if(file_exists($up_dir."wopmid/".$file_name)){
				$show_dl = "[<a href=\"".$up_dir."wopmid/".$file_name."\" target=\"_blank\">PDF</a>]";
			}
		}
		
		#xml
		if($id > 0){
			$PUB_XML = XOOPS_ROOT_PATH."/modules/PubMedPDF/pubmed_xml/".$id.".xml";
			$PUB_XML2 = XOOPS_URL."/modules/PubMedPDF/pubmed_xml/".$id.".xml";
			if(file_exists($PUB_XML)){
				$show_xml_dl = "[<a href=\"".$PUB_XML2."\" target=\"_blank\">XML</a>]";
			}
		
		}else{
			$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$id."'";
			$res = mysql_query($sql, $conn);
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			
			$UP_XML = XOOPS_ROOT_PATH."/modules/PubMedPDF/uploads_xml/".$row["Custom_t1"].".xml";
			$UP_XML2 = XOOPS_URL."/modules/PubMedPDF/uploads_xml/".$row["Custom_t1"].".xml";
			if(file_exists($UP_XML)){
				$show_xml_dl = "[<a href=\"".$UP_XML2."\" target=\"_blank\">XML</a>]";
			}
		}
		

		# head color
		($show_dl) ? $class="head" : $class="even";
		
		#id
		if ($id > 0 ) {
			$id = "<a  target=\"_blank\" href=\"http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=search&term=".$id."\">".$id."</a>";
			$edit = "";
			$pid = "PMID[".$id."]";
		} else {
			$id = -$id;
			if($r_usr == $user){
				$edit = "[<a href=\"edit_wopmid.php?id=$id\">remove/edit</a>]";
			}elseif(Check_permission($user)){
				$edit = "[<a href=\"edit_wopmid.php?id=$id\">remove/edit</a>]";
			}else{
				$edit = "";
			}
			$pid = "";
		}

		if ( strlen($t_jp) ) $title = $t_jp; else $title = $t;
		if ( strlen($a_jp) ) $author = $a_jp;
		if ( strlen($j_jp) ) $journal = $j_jp; else $journal = $j;
		echo <<<E
		<table class="outer" style="width:100%">
		<tr><td colspan="2" class="$class">$title</td></tr>
		<tr><td colspan="2" class="even">$author</td></tr>
		<tr><td colspan="2" class="even" style="text-align:right">$journal &nbsp;$y-v$v-pp$p
		</td></tr>
		<tr>
			<td>$pid $edit $favorite $memo</td>
			<td style="text-align:right">
				 $show_ab $show_xml_dl $show_dl
			</td>
		</tr>
		</table>
		<br>
E;
	}
}

#------------------------------------------------------------------
# Javascript window for 'abstract', 'favorite', 'shortcut', 'note'
#------------------------------------------------------------------

	include("../../../mainfile.php");
	include "../style.php";
	include "conn.php";
	
	if ( file_exists("../language/".$xoopsConfig['language']."/main.php") ) {
		include "../language/".$xoopsConfig['language']."/main.php";
	} else {
		include "../language/english/main.php";
	}

	$day = getdate();
	$date = $day["year"] ."-". $day["mon"] ."-". $day["mday"];
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";

	echo <<<E
	<script type="text/javascript">
	function disp(url,w,h){
		window.open(url, "window_name", "width="+w+",height="+h+",scrollbars=yes,resizable=yes");
	}
	</script>
E;

#------------
# abstract
#------------
	if($id = @$_GET["abst"]){

		$sql = "SELECT Abstract FROM ".$T_ID." WHERE PMID='".$id."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		echo $row["Abstract"]."<br><br>";
		echo "<center><a href=\"javascript:window.close()\">close</a></center>";
	}
	
#-----------------------------
# abstract for PubMed Search
#-----------------------------

	if($abst = @$_GET["abst2"]){

		$abst = str_replace("\'","'",$abst);
		$abst = str_replace("\\\\","\"",$abst);
		echo $abst."<br><br><center><a href=\"javascript:window.close()\">close</a></center>";
	}

#------------
# favorite
#------------	
	if($pmid = @$_GET["pid"]){

		# get data id
		$sql = "SELECT id FROM ".$T_ID." WHERE PMID='".$pmid."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$id = $row["id"];

		# favorite directories
		echo "<form action=\"".$_SERVER[PHP_SELF]."\" method=\"GET\">";
		$d_id[] = "0";
		$d_name[] = "Top directory";
		$sql = "SELECT * FROM ".$T_FDIR." WHERE Usr='".$user."'";
		$res = mysql_query($sql, $conn);
		while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
			$d_id[] = $row["id"];
			$d_name[] = $row["Name"];
		}
		
		echo "<div class=\"pt\">"._MD_FAVO_ADD."</div>";
		echo "<div style=\"margin-bottom:10px\">&nbsp;&nbsp;"._MD_FAVO_WHICHD."</div>";
		echo "&nbsp;&nbsp;insert into <select name=\"dir\">";
		for($i=0; $i<count($d_id); $i++){
			echo "<option value=\"".$d_id[$i]."\">".$d_name[$i]."</option>";
		}
		echo "</select>";
		echo "<input type=\"submit\" value=\"submit\" name=\"favorite\">";
		echo "<input type=\"hidden\" name=\"pid2\" value=\"".$id."\">";
		echo "</form>";
	
	# insert into database
	}elseif(@$_GET["favorite"]){
	
		$id = intval(@$_GET["pid2"]);
		$d_id = intval(@$_GET["dir"]);

		$sql = "INSERT INTO ".$T_FDATA." VALUES('','".$id."','".$d_id."','".$user."','')";
		$res = mysql_query($sql, $conn);

		echo "<div class=\"pt\">"._MD_FAVO_ADD."</div>"._MD_FAVO_ADDED;
		echo <<<E
		<script>
		 setTimeout('window.close()', 1200);
		</script>
E;
	}
	
#------------
# shortcut
#------------
	if(@$_GET["make_s"]){

		$name = @$_GET["name"];
		$pass = str_replace("~~","?",@$_GET["pass"]);
		$pass = str_replace("^^","&",$pass);
		
		$sql = "SELECT * FROM ".$T_SCUT." WHERE Usr='".$user."' AND Target='".$pass."'";
		$res = mysql_query($sql, $conn);
		if(mysql_num_rows($res) <= 0){
			$sql = "INSERT INTO ".$T_SCUT." VALUES('','".$user."','".$name."','".$pass."')";
			$res = mysql_query($sql, $conn);
		}

		echo "<div class=\"pt\">"._MD_SCUT."</div>"._MD_SCUT_MADE;
		echo <<<E
		<script>
		 setTimeout('window.close()', 1200);
		</script>
E;
	}

#------------
# note
#------------
	$UPDIR = XOOPS_ROOT_PATH."/modules/PubMedPDF/up_files/";
	$UPDIR2 = XOOPS_URL."/modules/PubMedPDF/up_files/";
	if(!is_dir($UPDIR))	$rc = mkdir($UPDIR, 0777);
	
	if(@$_GET["mid"]){
		
		$id = intval(@$_GET["mid"]);
		echo "<center><table style=\"width:90%\"><tr><td>";

		//link
		echo "<div class=\"pt\" style=\"margin-top:20px;\">"._MD_NOTE."</div>";
		echo "<div style=\"text-align:right\">";
		echo "<a href=\"#public\" class=\"note_link\">["._MD_NOTE_PUB."]</a> ";
		echo "<a href=\"#private\" class=\"note_link\">["._MD_NOTE_PRI."]</a> ";
		echo "<a href=\"#new\" class=\"note_link\">["._MD_NOTE_NEW."]</a> ";
		echo "<a href=\"javascript:window.close()\" class=\"note_link\">["._MD_NOTE_CLOSE."]</a></div><br>";

		//public
		echo "<a name=\"public\"></a>";
		$sql = "SELECT * FROM ".$T_MEMO." WHERE data_id='".$id."' AND Public_flg='1' ORDER BY R_date DESC";
		$res = mysql_query($sql, $conn);
		if(mysql_num_rows($res) > 0){
			while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
				
				echo "<div class=\"note_info\">";
				echo $row["R_usr"]." (".$row["R_date"].", "._MD_NOTE_PUB.")";
				echo "</div>";

				echo "<table class=\"note\">";				
				echo "<tr class=\"content\"><td>".$row["Comment"]."</td></tr>";

				//uploaded file
				$up_name = $row["id"];
				$sql2 = "SELECT * FROM ".$T_TMP." WHERE tmp1='upfile_name_for_memo' AND tmp3 like '".$up_name.".%'";
				$res2 = mysql_query($sql2, $conn);
				if(mysql_num_rows($res2) > 0){
					$row2 = mysql_fetch_array($res2, MYSQL_ASSOC);
					$up_name = $UPDIR.$row2["tmp3"];
					$up_name2 = $UPDIR2.$row2["tmp3"];
					if(file_exists($up_name)){
						echo "<tr><td>";
						echo "<br><a href=\"".$up_name2."\" target=\"_blank\" class=\"note_info\">File Download</a></td></tr>";
					}
				}
				
				echo "</table>";

				echo "<div class=\"note_edit\">";
				if($row["R_usr"] == $user){
					echo "<a href=\"".$_SERVER[PHP_SELF]."?note_editid=".$row["id"]."\" style=\"text-decoration:none\">["._MD_NOTE_EDIT_C."]</a> ";
					echo "<a href=\"".$_SERVER[PHP_SELF]."?note_editid=".$row["id"]."&note_editmeth=del\" style=\"text-decoration:none\">["._MD_NOTE_EDIT_D."]</a>";
				}
				echo "</div>";
			}
		}
		
		//praivate
		echo "<a name=\"private\"></a>";
		$sql = "SELECT * FROM ".$T_MEMO." WHERE data_id='".$id."' AND Public_flg='0' AND R_usr='".$user."' ORDER BY R_date DESC";
		$res = mysql_query($sql, $conn);
		if(mysql_num_rows($res) > 0){
			while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
				echo "<div class=\"note_info\">";
				echo $row["R_usr"]." (".$row["R_date"].", "._MD_NOTE_PRI.")";
				echo "</div>";

				echo "<table class=\"note\">";				
				echo "<tr class=\"content\"><td>".$row["Comment"]."</td></tr>";
				
				//uploaded file
				$up_name = $row["id"];
				$sql2 = "SELECT * FROM ".$T_TMP." WHERE tmp1='upfile_name_for_memo' AND tmp3 like '".$up_name.".%'";
				$res2 = mysql_query($sql2, $conn);
				if(mysql_num_rows($res2) > 0){
					$row2 = mysql_fetch_array($res2, MYSQL_ASSOC);
					$up_name = $UPDIR.$row2["tmp3"];
					$up_name2 = $UPDIR2.$row2["tmp3"];
					if(file_exists($up_name)){
						echo "<tr><td>";
						echo "<br><a href=\"".$up_name2."\" target=\"_blank\" class=\"note_info\">File Download</a></td></tr>";
					}
				}
				
				echo "</table>";
					
				echo "<div class=\"note_edit\">";
				if($row["R_usr"] == $user){
					echo "<a href=\"".$_SERVER[PHP_SELF]."?note_editid=".$row["id"]."\" style=\"text-decoration:none\">["._MD_NOTE_EDIT_C."]</a> ";
					echo "<a href=\"".$_SERVER[PHP_SELF]."?note_editid=".$row["id"]."&note_editmeth=del\" style=\"text-decoration:none\">["._MD_NOTE_EDIT_D."]</a>";
				}
				echo "</div>";
			}
		}

		//new
		echo "<a name=\"new\"></a>";		
		echo "<div class=\"pt\" style=\"margin-top:20px;\">"._MD_NOTE_NEW2."</div>";
		echo "<form enctype=\"multipart/form-data\" action=\"".$_SERVER[PHP_SELF]."\" method=\"POST\">";
		echo "<textarea name=\"note\" rows=\"10\" style=\"width:100%\"></textarea><br>";
		echo "<br>źեե <input type=\"file\" name=\"userfile\"><br><br>";
		echo "<input type=\"radio\" value=\"1\" name=\"pflg\" checked>"._MD_NOTE_PUB." ";
		echo "<input type=\"radio\" value=\"0\" name=\"pflg\">"._MD_NOTE_PRI." <br><br>";
		echo "<input type=\"hidden\" value=\"".$id."\" name=\"note_id\">";
		echo "<input type=\"submit\" value=\"submit\" name=\"register_note\">";
		echo "</form>";
		echo "</td></tr></table></center>";		
	}

	# note edit form
	if(@$_GET["note_editid"]){
	
		$id = intval(@$_GET["note_editid"]);
		echo "<center><table style=\"width:90%\"><tr><td>";
		echo "<div class=\"pt\" style=\"margin-top:20px;\">"._MD_NOTE_EDIT."</div>";

		$sql = "SELECT * FROM ".$T_MEMO." WHERE id='".$id."'";
		$res = mysql_query($sql, $conn);
		if(mysql_num_rows($res) > 0){
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			if($row["R_usr"] == $user){
				$com = str_replace("<br />","\n",$row["Comment"]);

				# delete
				if(@$_GET["note_editmeth"]){
					echo _MD_NOTE_DEL."<br><br>".$com."<br><br>";
					echo "<form action=\"".$_SERVER[PHP_SELF]."\" method=\"POST\">";
					echo "<input type=\"hidden\" value=\"".$id."\" name=\"note_did\">";
					echo "<input type=\"submit\" value=\"yes\" name=\"register_note\">";
					echo "</form>";
									
				# edit
				}else{
					echo "<form enctype=\"multipart/form-data\" action=\"".$_SERVER[PHP_SELF]."\" method=\"POST\">";
					echo "<textarea name=\"note\" rows=\"10\" style=\"width:100%\">".$com."</textarea><br>";

					//file upload
					echo "<br><input type=\"radio\" name=\"file_edit\" value=\"delete\">źեեӽ<br>";
					echo "<input type=\"radio\" name=\"file_edit\" value=\"edit\">źեեѹ or ɲ&nbsp;&nbsp; ";
					echo "<input type=\"file\" name=\"userfile\"><br><br>";
					
					//public or private
					if($row["Public_flg"] == 1){
						echo "<input type=\"radio\" value=\"1\" name=\"pflg\" checked>"._MD_NOTE_PUB." ";
						echo "<input type=\"radio\" value=\"0\" name=\"pflg\">"._MD_NOTE_PRI." <br><br>";
					}else{
						echo "<input type=\"radio\" value=\"1\" name=\"pflg\">"._MD_NOTE_PUB." ";
						echo "<input type=\"radio\" value=\"0\" name=\"pflg\" checked>"._MD_NOTE_PRI." <br><br>";
					}
					
					echo "<input type=\"hidden\" value=\"".$id."\" name=\"note_eid\">";
					echo "<input type=\"hidden\" value=\"y\" name=\"note_edit\">";
					echo "<input type=\"submit\" value=\"submit\" name=\"register_note\">";
					echo "</form>";
				}
			}else{
				echo _MD_NOTE_PERMISSION_ERROR;
			}
		}else{
			echo _MD_NOTE_NODATA_ERROR;
		}
		echo "</td></tr></table></center>";
	}
	
	# note register / edit / delete
	if(@$_POST["register_note"]){

		$flg = intval(@$_POST["pflg"]);
		$string = @$_POST["note"];	
		$myts =& MyTextSanitizer::getInstance();
		$string = htmlspecialchars($string);
		$string = $myts -> makeTareaData4Show($string);
		$string = nl2br($string);

		echo "<center><br><table style=\"width:90%\"><tr><td>";
		
		//edit
		if(@$_POST["note_edit"]){
			$id = intval(@$_POST["note_eid"]);
			$sql = "UPDATE ".$T_MEMO." SET Comment='".$string."', Public_flg='".$flg."', R_date='".$date."' WHERE id=\"".$id."\"";
			$res = mysql_query($sql, $conn);

			//uploaded file
			if($upfile_method = @$_POST["file_edit"]){
				if($upfile_method == "delete"){
					$up_name = $id.".%";
					$sql = "SELECT * FROM ".$T_TMP." WHERE tmp1='upfile_name_for_memo' AND tmp3 like '".$up_name."'";
					$res = mysql_query($sql, $conn);
					if(mysql_num_rows($res) > 0){
						$row = mysql_fetch_array($res, MYSQL_ASSOC);
						$up_name = $UPDIR.$row["tmp3"];
						$up_name2 = $row["tmp3"];
						if(file_exists($up_name)){
							unlink($up_name);
							$sql = "DELETE FROM ".$T_TMP." WHERE tmp1='upfile_name_for_memo' AND tmp3='".$up_name2."'";
							$res = mysql_query($sql, $conn);
							$up_flg = "<br>źեեӽޤ";
						}
					}

				}elseif($upfile_method == "edit"){
					$up_name = $id.".%";
					$sql = "SELECT * FROM ".$T_TMP." WHERE tmp1='upfile_name_for_memo' AND tmp3 like '".$up_name."'";
					$res = mysql_query($sql, $conn);
					if(mysql_num_rows($res) > 0){
						$row = mysql_fetch_array($res, MYSQL_ASSOC);
						$old_name = $UPDIR.$row["tmp3"];
						$old_name2 = $row["tmp3"];
						if(file_exists($old_name)){
							unlink($old_name);
							$sql = "DELETE FROM ".$T_TMP." WHERE tmp1='upfile_name_for_memo' AND tmp3='".$old_name2."'";
							$res = mysql_query($sql, $conn);
						}
					}

					if(is_uploaded_file($_FILES['userfile']['tmp_name'])){
						$up_flg = 0;
						$up_name = $_FILES['userfile']['name'];
						$up_name = $id.substr($up_name, -4);
						copy($_FILES['userfile']['tmp_name'], $UPDIR.$up_name);
						$up_flg = "<br>ե뤬åץɤޤ";
						
						$sql = "INSERT INTO ".$T_TMP." VALUES('upfile_name_for_memo','','".$up_name."','')";
						$res = mysql_query($sql, $conn);
					}

				}
			}

			echo "<div class=\"pt\">"._MD_NOTE_EDIT."</div>";
			echo $string."<br>".$up_flg."<br>"._MD_NOTE_EDITED;
			
		//delete
		}elseif(@$_POST["note_did"]){
			$id = intval(@$_POST["note_did"]);
			$sql = "DELETE FROM ".$T_MEMO." WHERE id='".$id."'";
			$res = mysql_query($sql, $conn);
			
			//uploaded file delete
			$up_name = $id.".%";
			$sql = "SELECT * FROM ".$T_TMP." WHERE tmp1='upfile_name_for_memo' AND tmp3 like '".$up_name."'";
			$res = mysql_query($sql, $conn);
			if(mysql_num_rows($res) > 0){
				$row = mysql_fetch_array($res, MYSQL_ASSOC);
				$up_name = $UPDIR.$row["tmp3"];
				$up_name2 = $row["tmp3"];
				if(file_exists($up_name)){
					unlink($up_name);
					$sql = "DELETE FROM ".$T_TMP." WHERE tmp1='upfile_name_for_memo' AND tmp3 like '".$up_name2."'";
					$res = mysql_query($sql, $conn);
					$up_flg = "<br>źեեӽޤ";
				}
			}
			
			echo "<div class=\"pt\">"._MD_NOTE_EDIT."</div>";
			echo _MD_NOTE_DELETED.$up_flg;

		//new register
		}else{
			$id = intval(@$_POST["note_id"]);

			//memo register
			$sql = "INSERT INTO ".$T_MEMO." VALUES('','".$id."','".$user."','".$date."','".$string."','".$flg."')";
			$res = mysql_query($sql, $conn);
			$memo_id = mysql_insert_id($conn);

			//file upload
			if(is_uploaded_file($_FILES['userfile']['tmp_name'])){

				$up_flg = 0;
				$up_name = $_FILES['userfile']['name'];
				$up_name = $memo_id.substr($up_name, -4);
				copy($_FILES['userfile']['tmp_name'], $UPDIR.$up_name);
				$up_flg = "<br>ե뤬åץɤޤ";
				
				//xoops_pmid_tmp('upfile_name_for_memo','','file name','')
				$sql = "INSERT INTO ".$T_TMP." VALUES('upfile_name_for_memo','','".$up_name."','')";
				$res = mysql_query($sql, $conn);
			}
			
			echo "<div class=\"pt\">"._MD_NOTE."</div>";
			echo $string."<br>".$up_flg."<br>"._MD_NOTE_ADDED;
		}

		echo "<br><a href=\"javascript:window.close()\" style=\"text-decoration:none\">close</a>";
		echo "</td></tr></table></center>";

	}

?>

==> PPDF_1_3.zip: PubMedPDF/include/paper_desc.php <==
<?php
# PAPER_DESCRIPTION($array, $user, $access_perm)
#------------------------------------------------------------------
# ʸꥹȤΥƥץ졼
#
#   array[pmid], xoopsuser name, PDF access permission
#-------------------------------------------------------------------

function PAPER_DESCRIPTION($item, $user, $perm){

	include "conn.php";
	include "check_perm.php";
	include "wopmid.php";

	# upload directory(relative pass)
	$sql = "SELECT * FROM ".$T_CONFIG." WHERE conf_name='updir2'";
	$res = mysql_query($sql, $conn);
	$row = mysql_fetch_array($res, MYSQL_ASSOC);

	$up_dir = $row["conf_value"];
	if(substr($up_dir,-1) != "/") $up_dir.="/";

	# show data
	for($i=0; $i<count($item); $i++){

		$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$item[$i]."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);

		$id = $item[$i];
		$a = $row["Author"];
		$t = $row["Title"];
		$v = $row["Volume"];
		$p = $row["Page"];
		$y = $row["Year"];
		$j = $row["Journal"];
		$abst = $row["Abstract"];
		$a_jp = $row["Author_JP"];
		$t_jp = $row["Title_JP"];
		$r_usr = $row["R_usr"];
		$f_num = "(".$row["F_num"].")";
	
		# get authors from database
		$author="";
		$a = explode(",",substr($a,0,-1));
		for($k=0; $k<count($a); $k++){
			$a[$k] = str_replace("[","",$a[$k]);
			$a[$k] = str_replace("]","",$a[$k]);
			$sql = "SELECT Author FROM ".$T_AUTHOR." WHERE id='".$a[$k]."'";
			$res = mysql_query($sql, $conn);
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			$author.=$row["Author"].", ";
		}
		$author = substr($author,0,-2);

		# get journal from database
		$sql = "SELECT Journal,Journal_JP FROM ".$T_JOURNAL." WHERE id='".$j."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$j = $row["Journal"];
		$j_jp = $row["Journal_JP"];

		# abstract
		$show_ab = "";
		if($abst){			
			$show_ab = "[<a href=\"javascript:disp('include/show_abst.php?abst=".$id."',500,300)\">Abstract</a>]";
		}
		
		#favorite
		$favorite = "[<a href=\"javascript:disp('include/reg_favorite.php?pid=".$id."',500,110)\">favorite ".$f_num."</a>]";
	
		#note
		$memo = "[<a href=\"javascript:disp('include/note.php?mid=".$id."',650,600)\">note ";
		 #private note num
		$sql = "SELECT * FROM ".$T_MEMO." WHERE data_id='".$id."' AND Public_flg='0' AND R_usr='".$user."'";
		$res = mysql_query($sql, $conn);
		$memo.= "(".mysql_num_rows($res);
		 #public note num
		$sql = "SELECT * FROM ".$T_MEMO." WHERE data_id='".$id."' AND Public_flg='1'";
		$res = mysql_query($sql, $conn);
		$memo.= "/".mysql_num_rows($res).")";
		$memo.= "</a>]";
	
		# download
		$show_dl="";
//		if($perm){
		if($id > 0){
			if(file_exists($up_dir.$id.".pdf")){
				$show_dl = "[<a href=\"".$up_dir.$id.".pdf\" target=\"_blank\">PDF</a>]";
				$class = "head";
			}else{
				$show_dl = "[<a href=\"javascript:disp('pdf_add.php?id=".$id."',300,120)\">upload</a>]";
				$class = "even";
			}
		}else{
			$title = trim( $t );
//			$title = substr( $title, 0, 10 );
/*
			$file_name = $y."_".$author."_".$j."_".$v."_".$p."_".$title;
			$file_name = str_replace( array(' ', ','), array('_', '~'), $file_name );
*/
			$file_name = wopmid($y, $author, $j, $v, $p, $title);
			$file_name = $file_name.".pdf";

			if(file_exists($up_dir."wopmid/".$file_name)){
				$show_dl = "[<a href=\"".$up_dir."wopmid/".$file_name."\" target=\"_blank\">PDF</a>]";
				$class = "head";
			}else{
				$show_dl = "[<a href=\"javascript:disp('pdf_add_wopmid.php?id=".$id*(-1)."',300,120)\">upload</a>]";
				$class = "even";
			}
		}
//		}
		
		#xml
		if($id > 0){
			$PUB_XML = XOOPS_ROOT_PATH."/modules/PubMedPDF/pubmed_xml/".$id.".xml";
			$PUB_XML2 = XOOPS_URL."/modules/PubMedPDF/pubmed_xml/".$id.".xml";
			if(file_exists($PUB_XML)){
				$show_xml_dl = "[<a href=\"".$PUB_XML2."\" target=\"_blank\">XML</a>]";
			}
		
		}else{
			$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$id."'";
			$res = mysql_query($sql, $conn);
			$row = mysql_fetch_array($res, MYSQL_ASSOC);
			
			$UP_XML = XOOPS_ROOT_PATH."/modules/PubMedPDF/uploads_xml/".$row["Custom_t1"].".xml";
			$UP_XML2 = XOOPS_URL."/modules/PubMedPDF/uploads_xml/".$row["Custom_t1"].".xml";
			if(file_exists($UP_XML)){
				$show_xml_dl = "[<a href=\"".$UP_XML2."\" target=\"_blank\">XML</a>]";
			}
		}
				
		#id
		if ($id > 0 ) {
			$id = "<a  target=\"_blank\" href=\"http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=search&term=".$id."\">".$id."</a>";
			$edit = "";
			$pid = "PMID[".$id."]";
		} else {
			$id = -$id;
			if($r_usr == $user){
				$edit = "[<a href=\"edit_wopmid.php?id=$id\">remove/edit</a>]";
			}elseif(Check_permission($user)){
				$edit = "[<a href=\"edit_wopmid.php?id=$id\">remove/edit</a>]";
			}else{
				$edit = "";
			}
			$pid = "";
		}

		if ( strlen($t_jp) ) $title = $t_jp; else $title = $t;
		if ( strlen($a_jp) ) $author = $a_jp;
		if ( strlen($j_jp) ) $journal = $j_jp; else $journal = $j;
		echo <<<E
		<table class="outer" style="width:100%">
		<tr><td colspan="2" class="$class">$title</td></tr>
		<tr><td colspan="2" class="even">$author</td></tr>
		<tr><td colspan="2" class="even" style="text-align:right">$journal &nbsp;$y-v$v-pp$p
		</td></tr>
		<tr>
			<td>$pid $edit $favorite $memo</td>
			<td style="text-align:right">
				 $show_ab $show_xml_dl $show_dl
			</td>
		</tr>
		</table>
		<br>
E;
	}
}

?>
